@@ -568,13 +568,19 @@ L<Mojo::Message> can emit the following events.
 
 Emitted after message building or parsing is finished.
 
+  my $before = time;
+  $message->on(finish => sub {
+    my $message = shift;
+    $message->headers->header('X-Parser-Time' => time - $before);
+  });
+
 =head2 C<progress>
 
   $message->on(progress => sub {
     my $message = shift;
   });
 
-Emitted on progress.
+Emitted when message building or parsing makes progress.
 
 =head1 ATTRIBUTES
 
