@@ -10,19 +10,18 @@ use Mojo::Util 'md5_sum';
 #  Wishful thinking. We have long since evolved beyond the need for asses."
 sub register {
   my ($self, $app, $conf) = @_;
+  $conf ||= {};
 
   # Config
-  $conf ||= {};
   my $name     = $conf->{name}     || 'ep';
   my $template = $conf->{template} || {};
 
   # Custom sandbox
-  $template->{namespace} =
-    'Mojo::Template::SandBox::' . md5_sum(($ENV{MOJO_EXE} || ref $app) . $$)
-    unless defined $template->{namespace};
+  $template->{namespace} //=
+    'Mojo::Template::SandBox::' . md5_sum(($ENV{MOJO_EXE} || ref $app) . $$);
 
   # Auto escape by default to prevent XSS attacks
-  $template->{auto_escape} = 1 unless defined $template->{auto_escape};
+  $template->{auto_escape} //= 1;
 
   # Add "ep" handler
   $app->renderer->add_handler(
@@ -41,14 +40,9 @@ sub register {
       unless ($cache->get($key)) {
         my $mt = Mojo::Template->new($template);
 
-        # Self
-        my $prepend = 'my $self = shift;';
-
-        # Weaken
-        $prepend .= q/use Scalar::Util 'weaken'; weaken $self;/;
-
         # Be a bit more relaxed for helpers
-        $prepend .= q/no strict 'refs'; no warnings 'redefine';/;
+        my $prepend = q/my $self = shift; use Scalar::Util 'weaken';/
+          . q/weaken $self; no strict 'refs'; no warnings 'redefine';/;
 
         # Helpers
         $prepend .= 'my $_H = $self->app->renderer->helpers;';
